@@ -275,7 +275,7 @@ private:
   bool GetIsNull(size_type Row, Tuple::size_type Col) const;
   Field::size_type GetLength(size_type Row, Tuple::size_type Col) const;
 
-  friend class ConnectionItf;
+  friend class Connection_base;
   explicit Result(PGresult *rhs) : m_Result(rhs), m_Refcount(0) {MakeRef(rhs);}
   Result &operator=(PGresult *);
   bool operator!() const throw () { return !m_Result; }
