@@ -49,7 +49,7 @@ public:
    * @param C the connection this trigger resides in.
    * @param N a name for the trigger.
    */
-  Trigger(ConnectionItf &C, const PGSTD::string &N) : 			//[t4]
+  Trigger(Connection_base &C, const PGSTD::string &N) : 		//[t4]
     m_Conn(C), m_Name(N) { m_Conn.AddTrigger(this); }
 
   virtual ~Trigger() { m_Conn.RemoveTrigger(this); }			//[t4]
@@ -65,10 +65,10 @@ public:
   virtual void operator()(int be_pid) =0;				//[t4]
 
 protected:
-  ConnectionItf &Conn() const throw () { return m_Conn; }		//[t23]
+  Connection_base &Conn() const throw () { return m_Conn; }		//[t23]
 
 private:
-  ConnectionItf &m_Conn;
+  Connection_base &m_Conn;
   PGSTD::string m_Name;
 };
 
