@@ -51,6 +51,9 @@ int main(int, char *argv[])
   {
     LazyConnection C(argv[1]);
 
+    // See if Deactivate() behaves...
+    C.Deactivate();
+
     C.Perform(ReadTables());
   }
   catch (const sql_error &e)
